##  Strict Filtering with filters for fields on relations
Similarly, when using a filter for fields on relations, Landscape, and Matrix reports will correctly filter out relations that aren't in the scope of the selected filter:
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27428b127a4410149c7bd88a896440d3_LowRes.png) ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2743cdf37a44101498f094b15154e2ed_LowRes.png)
**Caution**
The inventory will not immediately reflect this change for now.
While Landscape and Matrix reports work with the strict filtering on relations and relation fields, the inventory will not work similarly.
